from .async_client import (
    CampaignCriterionServiceAsyncClient as CampaignCriterionServiceAsyncClient,
)
from .client import CampaignCriterionServiceClient as CampaignCriterionServiceClient

__all__ = ["CampaignCriterionServiceClient", "CampaignCriterionServiceAsyncClient"]
