from .async_client import CustomerServiceAsyncClient as CustomerServiceAsyncClient
from .client import CustomerServiceClient as CustomerServiceClient

__all__ = ["CustomerServiceClient", "CustomerServiceAsyncClient"]
