from .async_client import (
    CustomerManagerLinkServiceAsyncClient as CustomerManagerLinkServiceAsyncClient,
)
from .client import CustomerManagerLinkServiceClient as CustomerManagerLinkServiceClient

__all__ = ["CustomerManagerLinkServiceClient", "CustomerManagerLinkServiceAsyncClient"]
