from .async_client import BenchmarksServiceAsyncClient as BenchmarksServiceAsyncClient
from .client import BenchmarksServiceClient as BenchmarksServiceClient

__all__ = ["BenchmarksServiceClient", "BenchmarksServiceAsyncClient"]
