from .async_client import DataLinkServiceAsyncClient as DataLinkServiceAsyncClient
from .client import DataLinkServiceClient as DataLinkServiceClient

__all__ = ["DataLinkServiceClient", "DataLinkServiceAsyncClient"]
