from .ad_asset import (
    AdAppDeepLinkAsset as AdAppDeepLinkAsset,
    AdCallToActionAsset as AdCallToActionAsset,
    AdDemandGenCarouselCardAsset as AdDemandGenCarouselCardAsset,
    AdImageAsset as AdImageAsset,
    AdMediaBundleAsset as AdMediaBundleAsset,
    AdTextAsset as AdTextAsset,
    AdVideoAsset as AdVideoAsset,
    AdVideoAssetInfo as AdVideoAssetInfo,
    AdVideoAssetInventoryPreferences as AdVideoAssetInventoryPreferences,
    AdVideoAssetLinkFeatureControl as AdVideoAssetLinkFeatureControl,
)
from .ad_type_infos import (
    AppAdInfo as AppAdInfo,
    AppEngagementAdInfo as AppEngagementAdInfo,
    AppPreRegistrationAdInfo as AppPreRegistrationAdInfo,
    DemandGenCarouselAdInfo as DemandGenCarouselAdInfo,
    DemandGenMultiAssetAdInfo as DemandGenMultiAssetAdInfo,
    DemandGenProductAdInfo as DemandGenProductAdInfo,
    DemandGenVideoResponsiveAdInfo as DemandGenVideoResponsiveAdInfo,
    DisplayUploadAdInfo as DisplayUploadAdInfo,
    ExpandedDynamicSearchAdInfo as ExpandedDynamicSearchAdInfo,
    ExpandedTextAdInfo as ExpandedTextAdInfo,
    HotelAdInfo as HotelAdInfo,
    ImageAdInfo as ImageAdInfo,
    InFeedVideoAdInfo as InFeedVideoAdInfo,
    LegacyAppInstallAdInfo as LegacyAppInstallAdInfo,
    LegacyResponsiveDisplayAdInfo as LegacyResponsiveDisplayAdInfo,
    LocalAdInfo as LocalAdInfo,
    ResponsiveDisplayAdControlSpec as ResponsiveDisplayAdControlSpec,
    ResponsiveDisplayAdInfo as ResponsiveDisplayAdInfo,
    ResponsiveSearchAdInfo as ResponsiveSearchAdInfo,
    ShoppingComparisonListingAdInfo as ShoppingComparisonListingAdInfo,
    ShoppingProductAdInfo as ShoppingProductAdInfo,
    ShoppingSmartAdInfo as ShoppingSmartAdInfo,
    SmartCampaignAdInfo as SmartCampaignAdInfo,
    TextAdInfo as TextAdInfo,
    TravelAdInfo as TravelAdInfo,
    VideoAdInfo as VideoAdInfo,
    VideoBumperInStreamAdInfo as VideoBumperInStreamAdInfo,
    VideoNonSkippableInStreamAdInfo as VideoNonSkippableInStreamAdInfo,
    VideoOutstreamAdInfo as VideoOutstreamAdInfo,
    VideoResponsiveAdInfo as VideoResponsiveAdInfo,
    VideoTrueViewInStreamAdInfo as VideoTrueViewInStreamAdInfo,
    YouTubeAudioAdInfo as YouTubeAudioAdInfo,
)
from .additional_application_info import (
    AdditionalApplicationInfo as AdditionalApplicationInfo,
)
from .asset_policy import (
    AdAssetPolicySummary as AdAssetPolicySummary,
    AssetDisapproved as AssetDisapproved,
    AssetLinkPrimaryStatusDetails as AssetLinkPrimaryStatusDetails,
)
from .asset_set_types import (
    BusinessProfileBusinessNameFilter as BusinessProfileBusinessNameFilter,
    BusinessProfileLocationGroup as BusinessProfileLocationGroup,
    BusinessProfileLocationSet as BusinessProfileLocationSet,
    ChainFilter as ChainFilter,
    ChainLocationGroup as ChainLocationGroup,
    ChainSet as ChainSet,
    DynamicBusinessProfileLocationGroupFilter as DynamicBusinessProfileLocationGroupFilter,
    LocationSet as LocationSet,
    MapsLocationInfo as MapsLocationInfo,
    MapsLocationSet as MapsLocationSet,
)
from .asset_types import (
    AppDeepLinkAsset as AppDeepLinkAsset,
    BookOnGoogleAsset as BookOnGoogleAsset,
    BusinessMessageAsset as BusinessMessageAsset,
    BusinessMessageCallToActionInfo as BusinessMessageCallToActionInfo,
    BusinessProfileLocation as BusinessProfileLocation,
    CallAsset as CallAsset,
    CalloutAsset as CalloutAsset,
    CallToActionAsset as CallToActionAsset,
    DemandGenCarouselCardAsset as DemandGenCarouselCardAsset,
    DynamicCustomAsset as DynamicCustomAsset,
    DynamicEducationAsset as DynamicEducationAsset,
    DynamicFlightsAsset as DynamicFlightsAsset,
    DynamicHotelsAndRentalsAsset as DynamicHotelsAndRentalsAsset,
    DynamicJobsAsset as DynamicJobsAsset,
    DynamicLocalAsset as DynamicLocalAsset,
    DynamicRealEstateAsset as DynamicRealEstateAsset,
    DynamicTravelAsset as DynamicTravelAsset,
    FacebookMessengerBusinessMessageInfo as FacebookMessengerBusinessMessageInfo,
    HotelCalloutAsset as HotelCalloutAsset,
    HotelPropertyAsset as HotelPropertyAsset,
    ImageAsset as ImageAsset,
    ImageDimension as ImageDimension,
    LeadFormAsset as LeadFormAsset,
    LeadFormCustomQuestionField as LeadFormCustomQuestionField,
    LeadFormDeliveryMethod as LeadFormDeliveryMethod,
    LeadFormField as LeadFormField,
    LeadFormSingleChoiceAnswers as LeadFormSingleChoiceAnswers,
    LocationAsset as LocationAsset,
    MediaBundleAsset as MediaBundleAsset,
    MobileAppAsset as MobileAppAsset,
    PageFeedAsset as PageFeedAsset,
    PriceAsset as PriceAsset,
    PriceOffering as PriceOffering,
    PromotionAsset as PromotionAsset,
    PromotionBarcodeInfo as PromotionBarcodeInfo,
    PromotionQrCodeInfo as PromotionQrCodeInfo,
    SitelinkAsset as SitelinkAsset,
    StructuredSnippetAsset as StructuredSnippetAsset,
    TextAsset as TextAsset,
    WebhookDelivery as WebhookDelivery,
    WhatsappBusinessMessageInfo as WhatsappBusinessMessageInfo,
    YoutubeVideoAsset as YoutubeVideoAsset,
    YouTubeVideoListAsset as YouTubeVideoListAsset,
    ZaloBusinessMessageInfo as ZaloBusinessMessageInfo,
)
from .asset_usage import AssetUsage as AssetUsage
from .audience_insights_attribute import (
    AudienceInsightsAttribute as AudienceInsightsAttribute,
    AudienceInsightsAttributeMetadata as AudienceInsightsAttributeMetadata,
    AudienceInsightsAttributeMetadataGroup as AudienceInsightsAttributeMetadataGroup,
    AudienceInsightsCategory as AudienceInsightsCategory,
    AudienceInsightsEntity as AudienceInsightsEntity,
    AudienceInsightsLineup as AudienceInsightsLineup,
    KnowledgeGraphAttributeMetadata as KnowledgeGraphAttributeMetadata,
    LineupAttributeMetadata as LineupAttributeMetadata,
    LocationAttributeMetadata as LocationAttributeMetadata,
    UserInterestAttributeMetadata as UserInterestAttributeMetadata,
    UserListAttributeMetadata as UserListAttributeMetadata,
    YouTubeChannelAttributeMetadata as YouTubeChannelAttributeMetadata,
    YouTubeVideoAttributeMetadata as YouTubeVideoAttributeMetadata,
)
from .audiences import (
    AgeDimension as AgeDimension,
    AgeSegment as AgeSegment,
    AudienceDimension as AudienceDimension,
    AudienceExclusionDimension as AudienceExclusionDimension,
    AudienceSegment as AudienceSegment,
    AudienceSegmentDimension as AudienceSegmentDimension,
    CustomAudienceSegment as CustomAudienceSegment,
    DetailedDemographicSegment as DetailedDemographicSegment,
    ExclusionSegment as ExclusionSegment,
    GenderDimension as GenderDimension,
    HouseholdIncomeDimension as HouseholdIncomeDimension,
    LifeEventSegment as LifeEventSegment,
    ParentalStatusDimension as ParentalStatusDimension,
    UserInterestSegment as UserInterestSegment,
    UserListSegment as UserListSegment,
)
from .bidding import (
    Commission as Commission,
    EnhancedCpc as EnhancedCpc,
    FixedCpm as FixedCpm,
    FixedCpmTargetFrequencyGoalInfo as FixedCpmTargetFrequencyGoalInfo,
    ManualCpa as ManualCpa,
    ManualCpc as ManualCpc,
    ManualCpm as ManualCpm,
    ManualCpv as ManualCpv,
    MaximizeConversions as MaximizeConversions,
    MaximizeConversionValue as MaximizeConversionValue,
    PercentCpc as PercentCpc,
    TargetCpa as TargetCpa,
    TargetCpc as TargetCpc,
    TargetCpm as TargetCpm,
    TargetCpmTargetFrequencyGoal as TargetCpmTargetFrequencyGoal,
    TargetCpv as TargetCpv,
    TargetImpressionShare as TargetImpressionShare,
    TargetRoas as TargetRoas,
    TargetSpend as TargetSpend,
)
from .campaign_goal_settings import CampaignGoalSettings as CampaignGoalSettings
from .click_location import ClickLocation as ClickLocation
from .consent import Consent as Consent
from .criteria import (
    ActivityCityInfo as ActivityCityInfo,
    ActivityCountryInfo as ActivityCountryInfo,
    ActivityIdInfo as ActivityIdInfo,
    ActivityRatingInfo as ActivityRatingInfo,
    ActivityStateInfo as ActivityStateInfo,
    AddressInfo as AddressInfo,
    AdScheduleInfo as AdScheduleInfo,
    AgeRangeInfo as AgeRangeInfo,
    AppPaymentModelInfo as AppPaymentModelInfo,
    AudienceInfo as AudienceInfo,
    BrandInfo as BrandInfo,
    BrandListInfo as BrandListInfo,
    CarrierInfo as CarrierInfo,
    CombinedAudienceInfo as CombinedAudienceInfo,
    ContentLabelInfo as ContentLabelInfo,
    CustomAffinityInfo as CustomAffinityInfo,
    CustomAudienceInfo as CustomAudienceInfo,
    CustomIntentInfo as CustomIntentInfo,
    DeviceInfo as DeviceInfo,
    ExtendedDemographicInfo as ExtendedDemographicInfo,
    GenderInfo as GenderInfo,
    GeoPointInfo as GeoPointInfo,
    HotelAdvanceBookingWindowInfo as HotelAdvanceBookingWindowInfo,
    HotelCheckInDateRangeInfo as HotelCheckInDateRangeInfo,
    HotelCheckInDayInfo as HotelCheckInDayInfo,
    HotelCityInfo as HotelCityInfo,
    HotelClassInfo as HotelClassInfo,
    HotelCountryRegionInfo as HotelCountryRegionInfo,
    HotelDateSelectionTypeInfo as HotelDateSelectionTypeInfo,
    HotelIdInfo as HotelIdInfo,
    HotelLengthOfStayInfo as HotelLengthOfStayInfo,
    HotelStateInfo as HotelStateInfo,
    IncomeRangeInfo as IncomeRangeInfo,
    InteractionTypeInfo as InteractionTypeInfo,
    IpBlockInfo as IpBlockInfo,
    KeywordInfo as KeywordInfo,
    KeywordThemeInfo as KeywordThemeInfo,
    LanguageInfo as LanguageInfo,
    LifeEventInfo as LifeEventInfo,
    ListingDimensionInfo as ListingDimensionInfo,
    ListingDimensionPath as ListingDimensionPath,
    ListingGroupInfo as ListingGroupInfo,
    ListingScopeInfo as ListingScopeInfo,
    LocalServiceIdInfo as LocalServiceIdInfo,
    LocationGroupInfo as LocationGroupInfo,
    LocationInfo as LocationInfo,
    MobileAppCategoryInfo as MobileAppCategoryInfo,
    MobileApplicationInfo as MobileApplicationInfo,
    MobileDeviceInfo as MobileDeviceInfo,
    NegativeKeywordListInfo as NegativeKeywordListInfo,
    OperatingSystemVersionInfo as OperatingSystemVersionInfo,
    ParentalStatusInfo as ParentalStatusInfo,
    PlacementInfo as PlacementInfo,
    PlacementListInfo as PlacementListInfo,
    ProductBrandInfo as ProductBrandInfo,
    ProductCategoryInfo as ProductCategoryInfo,
    ProductChannelExclusivityInfo as ProductChannelExclusivityInfo,
    ProductChannelInfo as ProductChannelInfo,
    ProductConditionInfo as ProductConditionInfo,
    ProductCustomAttributeInfo as ProductCustomAttributeInfo,
    ProductGroupingInfo as ProductGroupingInfo,
    ProductItemIdInfo as ProductItemIdInfo,
    ProductLabelsInfo as ProductLabelsInfo,
    ProductLegacyConditionInfo as ProductLegacyConditionInfo,
    ProductTypeFullInfo as ProductTypeFullInfo,
    ProductTypeInfo as ProductTypeInfo,
    ProximityInfo as ProximityInfo,
    SearchThemeInfo as SearchThemeInfo,
    TopicInfo as TopicInfo,
    UnknownListingDimensionInfo as UnknownListingDimensionInfo,
    UserInterestInfo as UserInterestInfo,
    UserListInfo as UserListInfo,
    VerticalAdsItemGroupRuleInfo as VerticalAdsItemGroupRuleInfo,
    VerticalAdsItemGroupRuleListInfo as VerticalAdsItemGroupRuleListInfo,
    VideoLineupInfo as VideoLineupInfo,
    WebpageConditionInfo as WebpageConditionInfo,
    WebpageInfo as WebpageInfo,
    WebpageListInfo as WebpageListInfo,
    WebpageSampleInfo as WebpageSampleInfo,
    YouTubeChannelInfo as YouTubeChannelInfo,
    YouTubeVideoInfo as YouTubeVideoInfo,
)
from .criterion_category_availability import (
    CriterionCategoryAvailability as CriterionCategoryAvailability,
    CriterionCategoryChannelAvailability as CriterionCategoryChannelAvailability,
    CriterionCategoryLocaleAvailability as CriterionCategoryLocaleAvailability,
)
from .custom_parameter import CustomParameter as CustomParameter
from .customizer_value import CustomizerValue as CustomizerValue
from .dates import (
    DateRange as DateRange,
    YearMonth as YearMonth,
    YearMonthRange as YearMonthRange,
)
from .extensions import (
    CallFeedItem as CallFeedItem,
    CalloutFeedItem as CalloutFeedItem,
    SitelinkFeedItem as SitelinkFeedItem,
)
from .feed_common import Money as Money
from .final_app_url import FinalAppUrl as FinalAppUrl
from .frequency_cap import (
    FrequencyCapEntry as FrequencyCapEntry,
    FrequencyCapKey as FrequencyCapKey,
)
from .goal_common import (
    CustomerLifecycleOptimizationValueSettings as CustomerLifecycleOptimizationValueSettings,
)
from .goal_setting import GoalSetting as GoalSetting
from .keyword_plan_common import (
    ConceptGroup as ConceptGroup,
    HistoricalMetricsOptions as HistoricalMetricsOptions,
    KeywordAnnotations as KeywordAnnotations,
    KeywordConcept as KeywordConcept,
    KeywordPlanAggregateMetricResults as KeywordPlanAggregateMetricResults,
    KeywordPlanAggregateMetrics as KeywordPlanAggregateMetrics,
    KeywordPlanDeviceSearches as KeywordPlanDeviceSearches,
    KeywordPlanHistoricalMetrics as KeywordPlanHistoricalMetrics,
    MonthlySearchVolume as MonthlySearchVolume,
)
from .lifecycle_goals import LifecycleGoalValueSettings as LifecycleGoalValueSettings
from .local_services import (
    LocalServicesDocumentReadOnly as LocalServicesDocumentReadOnly,
)
from .metric_goal import MetricGoal as MetricGoal
from .metrics import Metrics as Metrics, SearchVolumeRange as SearchVolumeRange
from .offline_user_data import (
    CustomerMatchUserListMetadata as CustomerMatchUserListMetadata,
    EventAttribute as EventAttribute,
    EventItemAttribute as EventItemAttribute,
    ItemAttribute as ItemAttribute,
    OfflineUserAddressInfo as OfflineUserAddressInfo,
    ShoppingLoyalty as ShoppingLoyalty,
    StoreAttribute as StoreAttribute,
    StoreSalesMetadata as StoreSalesMetadata,
    StoreSalesThirdPartyMetadata as StoreSalesThirdPartyMetadata,
    TransactionAttribute as TransactionAttribute,
    UserAttribute as UserAttribute,
    UserData as UserData,
    UserIdentifier as UserIdentifier,
)
from .policy import (
    PolicyTopicConstraint as PolicyTopicConstraint,
    PolicyTopicEntry as PolicyTopicEntry,
    PolicyTopicEvidence as PolicyTopicEvidence,
    PolicyValidationParameter as PolicyValidationParameter,
    PolicyViolationKey as PolicyViolationKey,
)
from .policy_summary import PolicySummary as PolicySummary
from .real_time_bidding_setting import RealTimeBiddingSetting as RealTimeBiddingSetting
from .segments import (
    AssetInteractionTarget as AssetInteractionTarget,
    BudgetCampaignAssociationStatus as BudgetCampaignAssociationStatus,
    Keyword as Keyword,
    Segments as Segments,
    SkAdNetworkSourceApp as SkAdNetworkSourceApp,
)
from .simulation import (
    BudgetSimulationPoint as BudgetSimulationPoint,
    BudgetSimulationPointList as BudgetSimulationPointList,
    CpcBidSimulationPoint as CpcBidSimulationPoint,
    CpcBidSimulationPointList as CpcBidSimulationPointList,
    CpvBidSimulationPoint as CpvBidSimulationPoint,
    CpvBidSimulationPointList as CpvBidSimulationPointList,
    PercentCpcBidSimulationPoint as PercentCpcBidSimulationPoint,
    PercentCpcBidSimulationPointList as PercentCpcBidSimulationPointList,
    TargetCpaSimulationPoint as TargetCpaSimulationPoint,
    TargetCpaSimulationPointList as TargetCpaSimulationPointList,
    TargetImpressionShareSimulationPoint as TargetImpressionShareSimulationPoint,
    TargetImpressionShareSimulationPointList as TargetImpressionShareSimulationPointList,
    TargetRoasSimulationPoint as TargetRoasSimulationPoint,
    TargetRoasSimulationPointList as TargetRoasSimulationPointList,
)
from .tag_snippet import TagSnippet as TagSnippet
from .targeting_setting import (
    TargetingSetting as TargetingSetting,
    TargetRestriction as TargetRestriction,
    TargetRestrictionOperation as TargetRestrictionOperation,
)
from .text_label import TextLabel as TextLabel
from .third_party_integration_partners import (
    CampaignThirdPartyBrandLiftIntegrationPartner as CampaignThirdPartyBrandLiftIntegrationPartner,
    CampaignThirdPartyBrandSafetyIntegrationPartner as CampaignThirdPartyBrandSafetyIntegrationPartner,
    CampaignThirdPartyIntegrationPartners as CampaignThirdPartyIntegrationPartners,
    CampaignThirdPartyReachIntegrationPartner as CampaignThirdPartyReachIntegrationPartner,
    CampaignThirdPartyViewabilityIntegrationPartner as CampaignThirdPartyViewabilityIntegrationPartner,
    CustomerThirdPartyBrandLiftIntegrationPartner as CustomerThirdPartyBrandLiftIntegrationPartner,
    CustomerThirdPartyBrandSafetyIntegrationPartner as CustomerThirdPartyBrandSafetyIntegrationPartner,
    CustomerThirdPartyIntegrationPartners as CustomerThirdPartyIntegrationPartners,
    CustomerThirdPartyReachIntegrationPartner as CustomerThirdPartyReachIntegrationPartner,
    CustomerThirdPartyViewabilityIntegrationPartner as CustomerThirdPartyViewabilityIntegrationPartner,
    ThirdPartyIntegrationPartnerData as ThirdPartyIntegrationPartnerData,
)
from .url_collection import UrlCollection as UrlCollection
from .user_lists import (
    BasicUserListInfo as BasicUserListInfo,
    CrmBasedUserListInfo as CrmBasedUserListInfo,
    FlexibleRuleOperandInfo as FlexibleRuleOperandInfo,
    FlexibleRuleUserListInfo as FlexibleRuleUserListInfo,
    LogicalUserListInfo as LogicalUserListInfo,
    LogicalUserListOperandInfo as LogicalUserListOperandInfo,
    LookalikeUserListInfo as LookalikeUserListInfo,
    RuleBasedUserListInfo as RuleBasedUserListInfo,
    SimilarUserListInfo as SimilarUserListInfo,
    UserListActionInfo as UserListActionInfo,
    UserListDateRuleItemInfo as UserListDateRuleItemInfo,
    UserListLogicalRuleInfo as UserListLogicalRuleInfo,
    UserListNumberRuleItemInfo as UserListNumberRuleItemInfo,
    UserListRuleInfo as UserListRuleInfo,
    UserListRuleItemGroupInfo as UserListRuleItemGroupInfo,
    UserListRuleItemInfo as UserListRuleItemInfo,
    UserListStringRuleItemInfo as UserListStringRuleItemInfo,
)
from .value import Value as Value

__all__ = [
    "AdAppDeepLinkAsset",
    "AdCallToActionAsset",
    "AdDemandGenCarouselCardAsset",
    "AdImageAsset",
    "AdMediaBundleAsset",
    "AdTextAsset",
    "AdVideoAsset",
    "AdVideoAssetInfo",
    "AdVideoAssetInventoryPreferences",
    "AdVideoAssetLinkFeatureControl",
    "AppAdInfo",
    "AppEngagementAdInfo",
    "AppPreRegistrationAdInfo",
    "DemandGenCarouselAdInfo",
    "DemandGenMultiAssetAdInfo",
    "DemandGenProductAdInfo",
    "DemandGenVideoResponsiveAdInfo",
    "DisplayUploadAdInfo",
    "ExpandedDynamicSearchAdInfo",
    "ExpandedTextAdInfo",
    "HotelAdInfo",
    "ImageAdInfo",
    "InFeedVideoAdInfo",
    "LegacyAppInstallAdInfo",
    "LegacyResponsiveDisplayAdInfo",
    "LocalAdInfo",
    "ResponsiveDisplayAdControlSpec",
    "ResponsiveDisplayAdInfo",
    "ResponsiveSearchAdInfo",
    "ShoppingComparisonListingAdInfo",
    "ShoppingProductAdInfo",
    "ShoppingSmartAdInfo",
    "SmartCampaignAdInfo",
    "TextAdInfo",
    "TravelAdInfo",
    "VideoAdInfo",
    "VideoBumperInStreamAdInfo",
    "VideoNonSkippableInStreamAdInfo",
    "VideoOutstreamAdInfo",
    "VideoResponsiveAdInfo",
    "VideoTrueViewInStreamAdInfo",
    "YouTubeAudioAdInfo",
    "AdditionalApplicationInfo",
    "AdAssetPolicySummary",
    "AssetDisapproved",
    "AssetLinkPrimaryStatusDetails",
    "BusinessProfileBusinessNameFilter",
    "BusinessProfileLocationGroup",
    "BusinessProfileLocationSet",
    "ChainFilter",
    "ChainLocationGroup",
    "ChainSet",
    "DynamicBusinessProfileLocationGroupFilter",
    "LocationSet",
    "MapsLocationInfo",
    "MapsLocationSet",
    "AppDeepLinkAsset",
    "BookOnGoogleAsset",
    "BusinessMessageAsset",
    "BusinessMessageCallToActionInfo",
    "BusinessProfileLocation",
    "CallAsset",
    "CalloutAsset",
    "CallToActionAsset",
    "DemandGenCarouselCardAsset",
    "DynamicCustomAsset",
    "DynamicEducationAsset",
    "DynamicFlightsAsset",
    "DynamicHotelsAndRentalsAsset",
    "DynamicJobsAsset",
    "DynamicLocalAsset",
    "DynamicRealEstateAsset",
    "DynamicTravelAsset",
    "FacebookMessengerBusinessMessageInfo",
    "HotelCalloutAsset",
    "HotelPropertyAsset",
    "ImageAsset",
    "ImageDimension",
    "LeadFormAsset",
    "LeadFormCustomQuestionField",
    "LeadFormDeliveryMethod",
    "LeadFormField",
    "LeadFormSingleChoiceAnswers",
    "LocationAsset",
    "MediaBundleAsset",
    "MobileAppAsset",
    "PageFeedAsset",
    "PriceAsset",
    "PriceOffering",
    "PromotionAsset",
    "PromotionBarcodeInfo",
    "PromotionQrCodeInfo",
    "SitelinkAsset",
    "StructuredSnippetAsset",
    "TextAsset",
    "WebhookDelivery",
    "WhatsappBusinessMessageInfo",
    "YoutubeVideoAsset",
    "YouTubeVideoListAsset",
    "ZaloBusinessMessageInfo",
    "AssetUsage",
    "AudienceInsightsAttribute",
    "AudienceInsightsAttributeMetadata",
    "AudienceInsightsAttributeMetadataGroup",
    "AudienceInsightsCategory",
    "AudienceInsightsEntity",
    "AudienceInsightsLineup",
    "KnowledgeGraphAttributeMetadata",
    "LineupAttributeMetadata",
    "LocationAttributeMetadata",
    "UserInterestAttributeMetadata",
    "UserListAttributeMetadata",
    "YouTubeChannelAttributeMetadata",
    "YouTubeVideoAttributeMetadata",
    "AgeDimension",
    "AgeSegment",
    "AudienceDimension",
    "AudienceExclusionDimension",
    "AudienceSegment",
    "AudienceSegmentDimension",
    "CustomAudienceSegment",
    "DetailedDemographicSegment",
    "ExclusionSegment",
    "GenderDimension",
    "HouseholdIncomeDimension",
    "LifeEventSegment",
    "ParentalStatusDimension",
    "UserInterestSegment",
    "UserListSegment",
    "Commission",
    "EnhancedCpc",
    "FixedCpm",
    "FixedCpmTargetFrequencyGoalInfo",
    "ManualCpa",
    "ManualCpc",
    "ManualCpm",
    "ManualCpv",
    "MaximizeConversions",
    "MaximizeConversionValue",
    "PercentCpc",
    "TargetCpa",
    "TargetCpc",
    "TargetCpm",
    "TargetCpmTargetFrequencyGoal",
    "TargetCpv",
    "TargetImpressionShare",
    "TargetRoas",
    "TargetSpend",
    "CampaignGoalSettings",
    "ClickLocation",
    "Consent",
    "ActivityCityInfo",
    "ActivityCountryInfo",
    "ActivityIdInfo",
    "ActivityRatingInfo",
    "ActivityStateInfo",
    "AddressInfo",
    "AdScheduleInfo",
    "AgeRangeInfo",
    "AppPaymentModelInfo",
    "AudienceInfo",
    "BrandInfo",
    "BrandListInfo",
    "CarrierInfo",
    "CombinedAudienceInfo",
    "ContentLabelInfo",
    "CustomAffinityInfo",
    "CustomAudienceInfo",
    "CustomIntentInfo",
    "DeviceInfo",
    "ExtendedDemographicInfo",
    "GenderInfo",
    "GeoPointInfo",
    "HotelAdvanceBookingWindowInfo",
    "HotelCheckInDateRangeInfo",
    "HotelCheckInDayInfo",
    "HotelCityInfo",
    "HotelClassInfo",
    "HotelCountryRegionInfo",
    "HotelDateSelectionTypeInfo",
    "HotelIdInfo",
    "HotelLengthOfStayInfo",
    "HotelStateInfo",
    "IncomeRangeInfo",
    "InteractionTypeInfo",
    "IpBlockInfo",
    "KeywordInfo",
    "KeywordThemeInfo",
    "LanguageInfo",
    "LifeEventInfo",
    "ListingDimensionInfo",
    "ListingDimensionPath",
    "ListingGroupInfo",
    "ListingScopeInfo",
    "LocalServiceIdInfo",
    "LocationGroupInfo",
    "LocationInfo",
    "MobileAppCategoryInfo",
    "MobileApplicationInfo",
    "MobileDeviceInfo",
    "NegativeKeywordListInfo",
    "OperatingSystemVersionInfo",
    "ParentalStatusInfo",
    "PlacementInfo",
    "PlacementListInfo",
    "ProductBrandInfo",
    "ProductCategoryInfo",
    "ProductChannelExclusivityInfo",
    "ProductChannelInfo",
    "ProductConditionInfo",
    "ProductCustomAttributeInfo",
    "ProductGroupingInfo",
    "ProductItemIdInfo",
    "ProductLabelsInfo",
    "ProductLegacyConditionInfo",
    "ProductTypeFullInfo",
    "ProductTypeInfo",
    "ProximityInfo",
    "SearchThemeInfo",
    "TopicInfo",
    "UnknownListingDimensionInfo",
    "UserInterestInfo",
    "UserListInfo",
    "VerticalAdsItemGroupRuleInfo",
    "VerticalAdsItemGroupRuleListInfo",
    "VideoLineupInfo",
    "WebpageConditionInfo",
    "WebpageInfo",
    "WebpageListInfo",
    "WebpageSampleInfo",
    "YouTubeChannelInfo",
    "YouTubeVideoInfo",
    "CriterionCategoryAvailability",
    "CriterionCategoryChannelAvailability",
    "CriterionCategoryLocaleAvailability",
    "CustomParameter",
    "CustomizerValue",
    "DateRange",
    "YearMonth",
    "YearMonthRange",
    "CallFeedItem",
    "CalloutFeedItem",
    "SitelinkFeedItem",
    "Money",
    "FinalAppUrl",
    "FrequencyCapEntry",
    "FrequencyCapKey",
    "CustomerLifecycleOptimizationValueSettings",
    "GoalSetting",
    "ConceptGroup",
    "HistoricalMetricsOptions",
    "KeywordAnnotations",
    "KeywordConcept",
    "KeywordPlanAggregateMetricResults",
    "KeywordPlanAggregateMetrics",
    "KeywordPlanDeviceSearches",
    "KeywordPlanHistoricalMetrics",
    "MonthlySearchVolume",
    "LifecycleGoalValueSettings",
    "LocalServicesDocumentReadOnly",
    "MetricGoal",
    "Metrics",
    "SearchVolumeRange",
    "CustomerMatchUserListMetadata",
    "EventAttribute",
    "EventItemAttribute",
    "ItemAttribute",
    "OfflineUserAddressInfo",
    "ShoppingLoyalty",
    "StoreAttribute",
    "StoreSalesMetadata",
    "StoreSalesThirdPartyMetadata",
    "TransactionAttribute",
    "UserAttribute",
    "UserData",
    "UserIdentifier",
    "PolicyTopicConstraint",
    "PolicyTopicEntry",
    "PolicyTopicEvidence",
    "PolicyValidationParameter",
    "PolicyViolationKey",
    "PolicySummary",
    "RealTimeBiddingSetting",
    "AssetInteractionTarget",
    "BudgetCampaignAssociationStatus",
    "Keyword",
    "Segments",
    "SkAdNetworkSourceApp",
    "BudgetSimulationPoint",
    "BudgetSimulationPointList",
    "CpcBidSimulationPoint",
    "CpcBidSimulationPointList",
    "CpvBidSimulationPoint",
    "CpvBidSimulationPointList",
    "PercentCpcBidSimulationPoint",
    "PercentCpcBidSimulationPointList",
    "TargetCpaSimulationPoint",
    "TargetCpaSimulationPointList",
    "TargetImpressionShareSimulationPoint",
    "TargetImpressionShareSimulationPointList",
    "TargetRoasSimulationPoint",
    "TargetRoasSimulationPointList",
    "TagSnippet",
    "TargetingSetting",
    "TargetRestriction",
    "TargetRestrictionOperation",
    "TextLabel",
    "CampaignThirdPartyBrandLiftIntegrationPartner",
    "CampaignThirdPartyBrandSafetyIntegrationPartner",
    "CampaignThirdPartyIntegrationPartners",
    "CampaignThirdPartyReachIntegrationPartner",
    "CampaignThirdPartyViewabilityIntegrationPartner",
    "CustomerThirdPartyBrandLiftIntegrationPartner",
    "CustomerThirdPartyBrandSafetyIntegrationPartner",
    "CustomerThirdPartyIntegrationPartners",
    "CustomerThirdPartyReachIntegrationPartner",
    "CustomerThirdPartyViewabilityIntegrationPartner",
    "ThirdPartyIntegrationPartnerData",
    "UrlCollection",
    "BasicUserListInfo",
    "CrmBasedUserListInfo",
    "FlexibleRuleOperandInfo",
    "FlexibleRuleUserListInfo",
    "LogicalUserListInfo",
    "LogicalUserListOperandInfo",
    "LookalikeUserListInfo",
    "RuleBasedUserListInfo",
    "SimilarUserListInfo",
    "UserListActionInfo",
    "UserListDateRuleItemInfo",
    "UserListLogicalRuleInfo",
    "UserListNumberRuleItemInfo",
    "UserListRuleInfo",
    "UserListRuleItemGroupInfo",
    "UserListRuleItemInfo",
    "UserListStringRuleItemInfo",
    "Value",
]
