from .async_client import (
    CustomerLifecycleGoalServiceAsyncClient as CustomerLifecycleGoalServiceAsyncClient,
)
from .client import (
    CustomerLifecycleGoalServiceClient as CustomerLifecycleGoalServiceClient,
)

__all__ = [
    "CustomerLifecycleGoalServiceClient",
    "CustomerLifecycleGoalServiceAsyncClient",
]
