from .async_client import (
    SharedCriterionServiceAsyncClient as SharedCriterionServiceAsyncClient,
)
from .client import SharedCriterionServiceClient as SharedCriterionServiceClient

__all__ = ["SharedCriterionServiceClient", "SharedCriterionServiceAsyncClient"]
