from .async_client import (
    AudienceInsightsServiceAsyncClient as AudienceInsightsServiceAsyncClient,
)
from .client import AudienceInsightsServiceClient as AudienceInsightsServiceClient

__all__ = ["AudienceInsightsServiceClient", "AudienceInsightsServiceAsyncClient"]
