from .async_client import (
    AdGroupCriterionLabelServiceAsyncClient as AdGroupCriterionLabelServiceAsyncClient,
)
from .client import (
    AdGroupCriterionLabelServiceClient as AdGroupCriterionLabelServiceClient,
)

__all__ = [
    "AdGroupCriterionLabelServiceClient",
    "AdGroupCriterionLabelServiceAsyncClient",
]
