from .async_client import (
    CustomerConversionGoalServiceAsyncClient as CustomerConversionGoalServiceAsyncClient,
)
from .client import (
    CustomerConversionGoalServiceClient as CustomerConversionGoalServiceClient,
)

__all__ = [
    "CustomerConversionGoalServiceClient",
    "CustomerConversionGoalServiceAsyncClient",
]
