from .async_client import (
    RecommendationServiceAsyncClient as RecommendationServiceAsyncClient,
)
from .client import RecommendationServiceClient as RecommendationServiceClient

__all__ = ["RecommendationServiceClient", "RecommendationServiceAsyncClient"]
