from .async_client import (
    CampaignLabelServiceAsyncClient as CampaignLabelServiceAsyncClient,
)
from .client import CampaignLabelServiceClient as CampaignLabelServiceClient

__all__ = ["CampaignLabelServiceClient", "CampaignLabelServiceAsyncClient"]
