from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v23.enums.types.interaction_event_type import (
    InteractionEventTypeEnum,
)
from google.ads.googleads.v23.enums.types.quality_score_bucket import (
    QualityScoreBucketEnum,
)

_M = TypeVar("_M")

class Metrics(proto.Message):
    absolute_top_impression_percentage: float
    active_view_cpm: float
    active_view_ctr: float
    active_view_impressions: int
    active_view_measurability: float
    active_view_measurable_cost_micros: int
    active_view_measurable_impressions: int
    active_view_viewability: float
    all_conversions_from_interactions_rate: float
    all_conversions_value: float
    all_conversions_value_by_conversion_date: float
    all_new_customer_lifetime_value: float
    all_conversions: float
    all_conversions_by_conversion_date: float
    all_conversions_value_per_cost: float
    all_conversions_from_click_to_call: float
    all_conversions_from_directions: float
    all_conversions_from_interactions_value_per_interaction: float
    all_conversions_from_menu: float
    all_conversions_from_order: float
    all_conversions_from_other_engagement: float
    all_conversions_from_store_visit: float
    all_conversions_from_store_website: float
    auction_insight_search_absolute_top_impression_percentage: float
    auction_insight_search_impression_share: float
    auction_insight_search_outranking_share: float
    auction_insight_search_overlap_rate: float
    auction_insight_search_position_above_rate: float
    auction_insight_search_top_impression_percentage: float
    average_cost: float
    average_cpc: float
    average_cpe: float
    average_cpm: float
    trueview_average_cpv: float
    average_page_views: float
    average_time_on_site: float
    benchmark_average_max_cpc: float
    biddable_app_install_conversions: float
    biddable_app_post_install_conversions: float
    biddable_cohort_app_post_install_conversions: float
    benchmark_ctr: float
    bounce_rate: float
    clicks: int
    combined_clicks: int
    combined_clicks_per_query: float
    combined_queries: int
    content_budget_lost_impression_share: float
    content_impression_share: float
    conversion_last_received_request_date_time: str
    conversion_last_conversion_date: str
    content_rank_lost_impression_share: float
    conversions_from_interactions_rate: float
    conversions_value: float
    conversions_value_by_conversion_date: float
    new_customer_lifetime_value: float
    conversions_value_per_cost: float
    conversions_from_interactions_value_per_interaction: float
    conversions: float
    conversions_by_conversion_date: float
    cost_micros: int
    cost_per_all_conversions: float
    cost_per_conversion: float
    cost_per_current_model_attributed_conversion: float
    cross_device_conversions: float
    cross_device_conversions_by_conversion_date: float
    cross_device_conversions_value: float
    cross_device_conversions_value_micros: int
    cross_device_conversions_value_by_conversion_date: float
    ctr: float
    current_model_attributed_conversions: float
    current_model_attributed_conversions_from_interactions_rate: float
    current_model_attributed_conversions_from_interactions_value_per_interaction: float
    current_model_attributed_conversions_value: float
    current_model_attributed_conversions_value_per_cost: float
    engagement_rate: float
    engagements: int
    hotel_average_lead_value_micros: float
    hotel_commission_rate_micros: int
    hotel_expected_commission_cost: float
    hotel_price_difference_percentage: float
    hotel_eligible_impressions: int
    historical_creative_quality_score: QualityScoreBucketEnum.QualityScoreBucket
    historical_landing_page_quality_score: QualityScoreBucketEnum.QualityScoreBucket
    historical_quality_score: int
    historical_search_predicted_ctr: QualityScoreBucketEnum.QualityScoreBucket
    gmail_forwards: int
    gmail_saves: int
    gmail_secondary_clicks: int
    impressions_from_store_reach: int
    impressions: int
    interaction_rate: float
    interactions: int
    interaction_event_types: MutableSequence[
        InteractionEventTypeEnum.InteractionEventType
    ]
    invalid_click_rate: float
    invalid_clicks: int
    general_invalid_click_rate: float
    general_invalid_clicks: int
    message_chats: int
    message_impressions: int
    message_chat_rate: float
    mobile_friendly_clicks_percentage: float
    optimization_score_uplift: float
    optimization_score_url: str
    organic_clicks: int
    organic_clicks_per_query: float
    organic_impressions: int
    organic_impressions_per_query: float
    organic_queries: int
    percent_new_visitors: float
    phone_calls: int
    phone_impressions: int
    phone_through_rate: float
    relative_ctr: float
    search_absolute_top_impression_share: float
    search_budget_lost_absolute_top_impression_share: float
    search_budget_lost_impression_share: float
    search_budget_lost_top_impression_share: float
    search_click_share: float
    search_exact_match_impression_share: float
    search_impression_share: float
    search_rank_lost_absolute_top_impression_share: float
    search_rank_lost_impression_share: float
    search_rank_lost_top_impression_share: float
    search_top_impression_share: float
    search_volume: SearchVolumeRange
    speed_score: int
    average_target_cpa_micros: int
    average_target_roas: float
    top_impression_percentage: float
    valid_accelerated_mobile_pages_clicks_percentage: float
    value_per_all_conversions: float
    value_per_all_conversions_by_conversion_date: float
    value_per_conversion: float
    value_per_conversions_by_conversion_date: float
    value_per_current_model_attributed_conversion: float
    video_quartile_p100_rate: float
    video_quartile_p25_rate: float
    video_quartile_p50_rate: float
    video_quartile_p75_rate: float
    video_trueview_view_rate: float
    video_trueview_views: int
    view_through_conversions: int
    sk_ad_network_installs: int
    sk_ad_network_total_conversions: int
    publisher_purchased_clicks: int
    publisher_organic_clicks: int
    publisher_unknown_clicks: int
    all_conversions_from_location_asset_click_to_call: float
    all_conversions_from_location_asset_directions: float
    all_conversions_from_location_asset_menu: float
    all_conversions_from_location_asset_order: float
    all_conversions_from_location_asset_other_engagement: float
    all_conversions_from_location_asset_store_visits: float
    all_conversions_from_location_asset_website: float
    eligible_impressions_from_location_asset_store_reach: int
    view_through_conversions_from_location_asset_click_to_call: float
    view_through_conversions_from_location_asset_directions: float
    view_through_conversions_from_location_asset_menu: float
    view_through_conversions_from_location_asset_order: float
    view_through_conversions_from_location_asset_other_engagement: float
    view_through_conversions_from_location_asset_store_visits: float
    view_through_conversions_from_location_asset_website: float
    orders: float
    average_order_value_micros: int
    average_cart_size: float
    cost_of_goods_sold_micros: int
    gross_profit_micros: int
    gross_profit_margin: float
    revenue_micros: int
    units_sold: float
    cross_sell_cost_of_goods_sold_micros: int
    cross_sell_gross_profit_micros: int
    cross_sell_revenue_micros: int
    cross_sell_units_sold: float
    lead_cost_of_goods_sold_micros: int
    lead_gross_profit_micros: int
    lead_revenue_micros: int
    lead_units_sold: float
    unique_users: int
    average_impression_frequency_per_user: float
    linked_entities_count: int
    linked_sample_entities: MutableSequence[str]
    asset_pinned_total_count: int
    asset_pinned_as_headline_position_one_count: int
    asset_pinned_as_headline_position_two_count: int
    asset_pinned_as_headline_position_three_count: int
    asset_pinned_as_description_position_one_count: int
    asset_pinned_as_description_position_two_count: int
    store_visits_last_click_model_attributed_conversions: float
    results_conversions_purchase: float
    video_trueview_view_rate_in_feed: float
    video_trueview_view_rate_in_stream: float
    video_trueview_view_rate_shorts: float
    coviewed_impressions: int
    primary_impressions: int
    platform_comparable_conversions_from_interactions_rate: float
    platform_comparable_conversions: float
    platform_comparable_conversions_value: float
    platform_comparable_conversions_value_per_cost: float
    platform_comparable_conversions_by_conversion_date: float
    platform_comparable_conversions_value_by_conversion_date: float
    platform_comparable_conversions_from_interactions_value_per_interaction: float
    cost_per_platform_comparable_conversion: float
    value_per_platform_comparable_conversion: float
    value_per_platform_comparable_conversions_by_conversion_date: float
    cost_converted_currency_per_platform_comparable_conversion: float
    value_adjustment: float
    all_value_adjustment: float
    clicks_unique_query_clusters: int
    conversions_unique_query_clusters: int
    impressions_unique_query_clusters: int
    video_watch_time_duration_millis: int
    average_video_watch_time_duration_millis: int
    svr: int
    active_view_audibility_measurable_impressions: int
    active_view_audibility_measurable_impressions_rate: float
    active_view_audibility_invalid_measurable_impressions_rate: float
    active_view_audibility_invalid_givt_measurable_impressions_rate: float
    active_view_audible_impressions: int
    active_view_audible_impressions_rate: float
    active_view_audible_two_seconds_impressions: int
    active_view_audible_two_seconds_impressions_rate: float
    active_view_audible_thirty_seconds_impressions: int
    active_view_audible_thirty_seconds_impressions_rate: float
    active_view_audible_quartile_p25_rate: float
    active_view_audible_quartile_p50_rate: float
    active_view_audible_quartile_p75_rate: float
    active_view_audible_quartile_p100_rate: float
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        absolute_top_impression_percentage: float = ...,
        active_view_cpm: float = ...,
        active_view_ctr: float = ...,
        active_view_impressions: int = ...,
        active_view_measurability: float = ...,
        active_view_measurable_cost_micros: int = ...,
        active_view_measurable_impressions: int = ...,
        active_view_viewability: float = ...,
        all_conversions_from_interactions_rate: float = ...,
        all_conversions_value: float = ...,
        all_conversions_value_by_conversion_date: float = ...,
        all_new_customer_lifetime_value: float = ...,
        all_conversions: float = ...,
        all_conversions_by_conversion_date: float = ...,
        all_conversions_value_per_cost: float = ...,
        all_conversions_from_click_to_call: float = ...,
        all_conversions_from_directions: float = ...,
        all_conversions_from_interactions_value_per_interaction: float = ...,
        all_conversions_from_menu: float = ...,
        all_conversions_from_order: float = ...,
        all_conversions_from_other_engagement: float = ...,
        all_conversions_from_store_visit: float = ...,
        all_conversions_from_store_website: float = ...,
        auction_insight_search_absolute_top_impression_percentage: float = ...,
        auction_insight_search_impression_share: float = ...,
        auction_insight_search_outranking_share: float = ...,
        auction_insight_search_overlap_rate: float = ...,
        auction_insight_search_position_above_rate: float = ...,
        auction_insight_search_top_impression_percentage: float = ...,
        average_cost: float = ...,
        average_cpc: float = ...,
        average_cpe: float = ...,
        average_cpm: float = ...,
        trueview_average_cpv: float = ...,
        average_page_views: float = ...,
        average_time_on_site: float = ...,
        benchmark_average_max_cpc: float = ...,
        biddable_app_install_conversions: float = ...,
        biddable_app_post_install_conversions: float = ...,
        biddable_cohort_app_post_install_conversions: float = ...,
        benchmark_ctr: float = ...,
        bounce_rate: float = ...,
        clicks: int = ...,
        combined_clicks: int = ...,
        combined_clicks_per_query: float = ...,
        combined_queries: int = ...,
        content_budget_lost_impression_share: float = ...,
        content_impression_share: float = ...,
        conversion_last_received_request_date_time: str = ...,
        conversion_last_conversion_date: str = ...,
        content_rank_lost_impression_share: float = ...,
        conversions_from_interactions_rate: float = ...,
        conversions_value: float = ...,
        conversions_value_by_conversion_date: float = ...,
        new_customer_lifetime_value: float = ...,
        conversions_value_per_cost: float = ...,
        conversions_from_interactions_value_per_interaction: float = ...,
        conversions: float = ...,
        conversions_by_conversion_date: float = ...,
        cost_micros: int = ...,
        cost_per_all_conversions: float = ...,
        cost_per_conversion: float = ...,
        cost_per_current_model_attributed_conversion: float = ...,
        cross_device_conversions: float = ...,
        cross_device_conversions_by_conversion_date: float = ...,
        cross_device_conversions_value: float = ...,
        cross_device_conversions_value_micros: int = ...,
        cross_device_conversions_value_by_conversion_date: float = ...,
        ctr: float = ...,
        current_model_attributed_conversions: float = ...,
        current_model_attributed_conversions_from_interactions_rate: float = ...,
        current_model_attributed_conversions_from_interactions_value_per_interaction: float = ...,
        current_model_attributed_conversions_value: float = ...,
        current_model_attributed_conversions_value_per_cost: float = ...,
        engagement_rate: float = ...,
        engagements: int = ...,
        hotel_average_lead_value_micros: float = ...,
        hotel_commission_rate_micros: int = ...,
        hotel_expected_commission_cost: float = ...,
        hotel_price_difference_percentage: float = ...,
        hotel_eligible_impressions: int = ...,
        historical_creative_quality_score: QualityScoreBucketEnum.QualityScoreBucket = ...,
        historical_landing_page_quality_score: QualityScoreBucketEnum.QualityScoreBucket = ...,
        historical_quality_score: int = ...,
        historical_search_predicted_ctr: QualityScoreBucketEnum.QualityScoreBucket = ...,
        gmail_forwards: int = ...,
        gmail_saves: int = ...,
        gmail_secondary_clicks: int = ...,
        impressions_from_store_reach: int = ...,
        impressions: int = ...,
        interaction_rate: float = ...,
        interactions: int = ...,
        interaction_event_types: MutableSequence[
            InteractionEventTypeEnum.InteractionEventType
        ] = ...,
        invalid_click_rate: float = ...,
        invalid_clicks: int = ...,
        general_invalid_click_rate: float = ...,
        general_invalid_clicks: int = ...,
        message_chats: int = ...,
        message_impressions: int = ...,
        message_chat_rate: float = ...,
        mobile_friendly_clicks_percentage: float = ...,
        optimization_score_uplift: float = ...,
        optimization_score_url: str = ...,
        organic_clicks: int = ...,
        organic_clicks_per_query: float = ...,
        organic_impressions: int = ...,
        organic_impressions_per_query: float = ...,
        organic_queries: int = ...,
        percent_new_visitors: float = ...,
        phone_calls: int = ...,
        phone_impressions: int = ...,
        phone_through_rate: float = ...,
        relative_ctr: float = ...,
        search_absolute_top_impression_share: float = ...,
        search_budget_lost_absolute_top_impression_share: float = ...,
        search_budget_lost_impression_share: float = ...,
        search_budget_lost_top_impression_share: float = ...,
        search_click_share: float = ...,
        search_exact_match_impression_share: float = ...,
        search_impression_share: float = ...,
        search_rank_lost_absolute_top_impression_share: float = ...,
        search_rank_lost_impression_share: float = ...,
        search_rank_lost_top_impression_share: float = ...,
        search_top_impression_share: float = ...,
        search_volume: SearchVolumeRange = ...,
        speed_score: int = ...,
        average_target_cpa_micros: int = ...,
        average_target_roas: float = ...,
        top_impression_percentage: float = ...,
        valid_accelerated_mobile_pages_clicks_percentage: float = ...,
        value_per_all_conversions: float = ...,
        value_per_all_conversions_by_conversion_date: float = ...,
        value_per_conversion: float = ...,
        value_per_conversions_by_conversion_date: float = ...,
        value_per_current_model_attributed_conversion: float = ...,
        video_quartile_p100_rate: float = ...,
        video_quartile_p25_rate: float = ...,
        video_quartile_p50_rate: float = ...,
        video_quartile_p75_rate: float = ...,
        video_trueview_view_rate: float = ...,
        video_trueview_views: int = ...,
        view_through_conversions: int = ...,
        sk_ad_network_installs: int = ...,
        sk_ad_network_total_conversions: int = ...,
        publisher_purchased_clicks: int = ...,
        publisher_organic_clicks: int = ...,
        publisher_unknown_clicks: int = ...,
        all_conversions_from_location_asset_click_to_call: float = ...,
        all_conversions_from_location_asset_directions: float = ...,
        all_conversions_from_location_asset_menu: float = ...,
        all_conversions_from_location_asset_order: float = ...,
        all_conversions_from_location_asset_other_engagement: float = ...,
        all_conversions_from_location_asset_store_visits: float = ...,
        all_conversions_from_location_asset_website: float = ...,
        eligible_impressions_from_location_asset_store_reach: int = ...,
        view_through_conversions_from_location_asset_click_to_call: float = ...,
        view_through_conversions_from_location_asset_directions: float = ...,
        view_through_conversions_from_location_asset_menu: float = ...,
        view_through_conversions_from_location_asset_order: float = ...,
        view_through_conversions_from_location_asset_other_engagement: float = ...,
        view_through_conversions_from_location_asset_store_visits: float = ...,
        view_through_conversions_from_location_asset_website: float = ...,
        orders: float = ...,
        average_order_value_micros: int = ...,
        average_cart_size: float = ...,
        cost_of_goods_sold_micros: int = ...,
        gross_profit_micros: int = ...,
        gross_profit_margin: float = ...,
        revenue_micros: int = ...,
        units_sold: float = ...,
        cross_sell_cost_of_goods_sold_micros: int = ...,
        cross_sell_gross_profit_micros: int = ...,
        cross_sell_revenue_micros: int = ...,
        cross_sell_units_sold: float = ...,
        lead_cost_of_goods_sold_micros: int = ...,
        lead_gross_profit_micros: int = ...,
        lead_revenue_micros: int = ...,
        lead_units_sold: float = ...,
        unique_users: int = ...,
        average_impression_frequency_per_user: float = ...,
        linked_entities_count: int = ...,
        linked_sample_entities: MutableSequence[str] = ...,
        asset_pinned_total_count: int = ...,
        asset_pinned_as_headline_position_one_count: int = ...,
        asset_pinned_as_headline_position_two_count: int = ...,
        asset_pinned_as_headline_position_three_count: int = ...,
        asset_pinned_as_description_position_one_count: int = ...,
        asset_pinned_as_description_position_two_count: int = ...,
        store_visits_last_click_model_attributed_conversions: float = ...,
        results_conversions_purchase: float = ...,
        video_trueview_view_rate_in_feed: float = ...,
        video_trueview_view_rate_in_stream: float = ...,
        video_trueview_view_rate_shorts: float = ...,
        coviewed_impressions: int = ...,
        primary_impressions: int = ...,
        platform_comparable_conversions_from_interactions_rate: float = ...,
        platform_comparable_conversions: float = ...,
        platform_comparable_conversions_value: float = ...,
        platform_comparable_conversions_value_per_cost: float = ...,
        platform_comparable_conversions_by_conversion_date: float = ...,
        platform_comparable_conversions_value_by_conversion_date: float = ...,
        platform_comparable_conversions_from_interactions_value_per_interaction: float = ...,
        cost_per_platform_comparable_conversion: float = ...,
        value_per_platform_comparable_conversion: float = ...,
        value_per_platform_comparable_conversions_by_conversion_date: float = ...,
        cost_converted_currency_per_platform_comparable_conversion: float = ...,
        value_adjustment: float = ...,
        all_value_adjustment: float = ...,
        clicks_unique_query_clusters: int = ...,
        conversions_unique_query_clusters: int = ...,
        impressions_unique_query_clusters: int = ...,
        video_watch_time_duration_millis: int = ...,
        average_video_watch_time_duration_millis: int = ...,
        svr: int = ...,
        active_view_audibility_measurable_impressions: int = ...,
        active_view_audibility_measurable_impressions_rate: float = ...,
        active_view_audibility_invalid_measurable_impressions_rate: float = ...,
        active_view_audibility_invalid_givt_measurable_impressions_rate: float = ...,
        active_view_audible_impressions: int = ...,
        active_view_audible_impressions_rate: float = ...,
        active_view_audible_two_seconds_impressions: int = ...,
        active_view_audible_two_seconds_impressions_rate: float = ...,
        active_view_audible_thirty_seconds_impressions: int = ...,
        active_view_audible_thirty_seconds_impressions_rate: float = ...,
        active_view_audible_quartile_p25_rate: float = ...,
        active_view_audible_quartile_p50_rate: float = ...,
        active_view_audible_quartile_p75_rate: float = ...,
        active_view_audible_quartile_p100_rate: float = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "absolute_top_impression_percentage",
            "active_view_cpm",
            "active_view_ctr",
            "active_view_impressions",
            "active_view_measurability",
            "active_view_measurable_cost_micros",
            "active_view_measurable_impressions",
            "active_view_viewability",
            "all_conversions_from_interactions_rate",
            "all_conversions_value",
            "all_conversions_value_by_conversion_date",
            "all_new_customer_lifetime_value",
            "all_conversions",
            "all_conversions_by_conversion_date",
            "all_conversions_value_per_cost",
            "all_conversions_from_click_to_call",
            "all_conversions_from_directions",
            "all_conversions_from_interactions_value_per_interaction",
            "all_conversions_from_menu",
            "all_conversions_from_order",
            "all_conversions_from_other_engagement",
            "all_conversions_from_store_visit",
            "all_conversions_from_store_website",
            "auction_insight_search_absolute_top_impression_percentage",
            "auction_insight_search_impression_share",
            "auction_insight_search_outranking_share",
            "auction_insight_search_overlap_rate",
            "auction_insight_search_position_above_rate",
            "auction_insight_search_top_impression_percentage",
            "average_cost",
            "average_cpc",
            "average_cpe",
            "average_cpm",
            "trueview_average_cpv",
            "average_page_views",
            "average_time_on_site",
            "benchmark_average_max_cpc",
            "biddable_app_install_conversions",
            "biddable_app_post_install_conversions",
            "biddable_cohort_app_post_install_conversions",
            "benchmark_ctr",
            "bounce_rate",
            "clicks",
            "combined_clicks",
            "combined_clicks_per_query",
            "combined_queries",
            "content_budget_lost_impression_share",
            "content_impression_share",
            "conversion_last_received_request_date_time",
            "conversion_last_conversion_date",
            "content_rank_lost_impression_share",
            "conversions_from_interactions_rate",
            "conversions_value",
            "conversions_value_by_conversion_date",
            "new_customer_lifetime_value",
            "conversions_value_per_cost",
            "conversions_from_interactions_value_per_interaction",
            "conversions",
            "conversions_by_conversion_date",
            "cost_micros",
            "cost_per_all_conversions",
            "cost_per_conversion",
            "cost_per_current_model_attributed_conversion",
            "cross_device_conversions",
            "cross_device_conversions_by_conversion_date",
            "cross_device_conversions_value",
            "cross_device_conversions_value_micros",
            "cross_device_conversions_value_by_conversion_date",
            "ctr",
            "current_model_attributed_conversions",
            "current_model_attributed_conversions_from_interactions_rate",
            "current_model_attributed_conversions_from_interactions_value_per_interaction",
            "current_model_attributed_conversions_value",
            "current_model_attributed_conversions_value_per_cost",
            "engagement_rate",
            "engagements",
            "hotel_average_lead_value_micros",
            "hotel_commission_rate_micros",
            "hotel_expected_commission_cost",
            "hotel_price_difference_percentage",
            "hotel_eligible_impressions",
            "historical_creative_quality_score",
            "historical_landing_page_quality_score",
            "historical_quality_score",
            "historical_search_predicted_ctr",
            "gmail_forwards",
            "gmail_saves",
            "gmail_secondary_clicks",
            "impressions_from_store_reach",
            "impressions",
            "interaction_rate",
            "interactions",
            "interaction_event_types",
            "invalid_click_rate",
            "invalid_clicks",
            "general_invalid_click_rate",
            "general_invalid_clicks",
            "message_chats",
            "message_impressions",
            "message_chat_rate",
            "mobile_friendly_clicks_percentage",
            "optimization_score_uplift",
            "optimization_score_url",
            "organic_clicks",
            "organic_clicks_per_query",
            "organic_impressions",
            "organic_impressions_per_query",
            "organic_queries",
            "percent_new_visitors",
            "phone_calls",
            "phone_impressions",
            "phone_through_rate",
            "relative_ctr",
            "search_absolute_top_impression_share",
            "search_budget_lost_absolute_top_impression_share",
            "search_budget_lost_impression_share",
            "search_budget_lost_top_impression_share",
            "search_click_share",
            "search_exact_match_impression_share",
            "search_impression_share",
            "search_rank_lost_absolute_top_impression_share",
            "search_rank_lost_impression_share",
            "search_rank_lost_top_impression_share",
            "search_top_impression_share",
            "search_volume",
            "speed_score",
            "average_target_cpa_micros",
            "average_target_roas",
            "top_impression_percentage",
            "valid_accelerated_mobile_pages_clicks_percentage",
            "value_per_all_conversions",
            "value_per_all_conversions_by_conversion_date",
            "value_per_conversion",
            "value_per_conversions_by_conversion_date",
            "value_per_current_model_attributed_conversion",
            "video_quartile_p100_rate",
            "video_quartile_p25_rate",
            "video_quartile_p50_rate",
            "video_quartile_p75_rate",
            "video_trueview_view_rate",
            "video_trueview_views",
            "view_through_conversions",
            "sk_ad_network_installs",
            "sk_ad_network_total_conversions",
            "publisher_purchased_clicks",
            "publisher_organic_clicks",
            "publisher_unknown_clicks",
            "all_conversions_from_location_asset_click_to_call",
            "all_conversions_from_location_asset_directions",
            "all_conversions_from_location_asset_menu",
            "all_conversions_from_location_asset_order",
            "all_conversions_from_location_asset_other_engagement",
            "all_conversions_from_location_asset_store_visits",
            "all_conversions_from_location_asset_website",
            "eligible_impressions_from_location_asset_store_reach",
            "view_through_conversions_from_location_asset_click_to_call",
            "view_through_conversions_from_location_asset_directions",
            "view_through_conversions_from_location_asset_menu",
            "view_through_conversions_from_location_asset_order",
            "view_through_conversions_from_location_asset_other_engagement",
            "view_through_conversions_from_location_asset_store_visits",
            "view_through_conversions_from_location_asset_website",
            "orders",
            "average_order_value_micros",
            "average_cart_size",
            "cost_of_goods_sold_micros",
            "gross_profit_micros",
            "gross_profit_margin",
            "revenue_micros",
            "units_sold",
            "cross_sell_cost_of_goods_sold_micros",
            "cross_sell_gross_profit_micros",
            "cross_sell_revenue_micros",
            "cross_sell_units_sold",
            "lead_cost_of_goods_sold_micros",
            "lead_gross_profit_micros",
            "lead_revenue_micros",
            "lead_units_sold",
            "unique_users",
            "average_impression_frequency_per_user",
            "linked_entities_count",
            "linked_sample_entities",
            "asset_pinned_total_count",
            "asset_pinned_as_headline_position_one_count",
            "asset_pinned_as_headline_position_two_count",
            "asset_pinned_as_headline_position_three_count",
            "asset_pinned_as_description_position_one_count",
            "asset_pinned_as_description_position_two_count",
            "store_visits_last_click_model_attributed_conversions",
            "results_conversions_purchase",
            "video_trueview_view_rate_in_feed",
            "video_trueview_view_rate_in_stream",
            "video_trueview_view_rate_shorts",
            "coviewed_impressions",
            "primary_impressions",
            "platform_comparable_conversions_from_interactions_rate",
            "platform_comparable_conversions",
            "platform_comparable_conversions_value",
            "platform_comparable_conversions_value_per_cost",
            "platform_comparable_conversions_by_conversion_date",
            "platform_comparable_conversions_value_by_conversion_date",
            "platform_comparable_conversions_from_interactions_value_per_interaction",
            "cost_per_platform_comparable_conversion",
            "value_per_platform_comparable_conversion",
            "value_per_platform_comparable_conversions_by_conversion_date",
            "cost_converted_currency_per_platform_comparable_conversion",
            "value_adjustment",
            "all_value_adjustment",
            "clicks_unique_query_clusters",
            "conversions_unique_query_clusters",
            "impressions_unique_query_clusters",
            "video_watch_time_duration_millis",
            "average_video_watch_time_duration_millis",
            "svr",
            "active_view_audibility_measurable_impressions",
            "active_view_audibility_measurable_impressions_rate",
            "active_view_audibility_invalid_measurable_impressions_rate",
            "active_view_audibility_invalid_givt_measurable_impressions_rate",
            "active_view_audible_impressions",
            "active_view_audible_impressions_rate",
            "active_view_audible_two_seconds_impressions",
            "active_view_audible_two_seconds_impressions_rate",
            "active_view_audible_thirty_seconds_impressions",
            "active_view_audible_thirty_seconds_impressions_rate",
            "active_view_audible_quartile_p25_rate",
            "active_view_audible_quartile_p50_rate",
            "active_view_audible_quartile_p75_rate",
            "active_view_audible_quartile_p100_rate",
        ],
    ) -> bool: ...

class SearchVolumeRange(proto.Message):
    min_: int
    max_: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        min_: int = ...,
        max_: int = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["min_", "max_"]
    ) -> bool: ...
