from .async_client import (
    CustomerLabelServiceAsyncClient as CustomerLabelServiceAsyncClient,
)
from .client import CustomerLabelServiceClient as CustomerLabelServiceClient

__all__ = ["CustomerLabelServiceClient", "CustomerLabelServiceAsyncClient"]
